@@ -7,7 +7,8 @@ use solana_sdk::{
     transaction::TransactionError,
 };
 
-const MAX_UNITS: u32 = 1_400_000;
+pub const DEFAULT_UNITS: u32 = 200_000;
+pub const MAX_UNITS: u32 = 1_400_000;
 const MAX_HEAP_FRAME_BYTES: u32 = 256 * 1024;
 
 #[cfg(RUSTC_WITH_SPECIALIZATION)]
@@ -67,19 +68,14 @@ pub struct ComputeBudget {
 
 impl Default for ComputeBudget {
     fn default() -> Self {
-        Self::new(true)
+        Self::new(MAX_UNITS)
     }
 }
 
 impl ComputeBudget {
-    pub fn new(use_max_units_default: bool) -> Self {
-        let max_units = if use_max_units_default {
-            MAX_UNITS
-        } else {
-            200_000
-        } as u64;
+    pub fn new(max_units: u32) -> Self {
         ComputeBudget {
-            max_units,
+            max_units: max_units as u64,
             log_64_units: 100,
             create_program_address_units: 1500,
             invoke_units: 1000,
